@@ -23,7 +23,7 @@ from . import _is_pypy
 
 try:
     from test.support import no_tracing
-except ImportError:
+except ModuleNotFoundError:
     from functools import wraps
 
     def no_tracing(func):
@@ -600,7 +600,7 @@ class AbstractPickleTests(unittest.TestCase):
             s = self.dumps(l_, proto)
             x = self.loads(s)
             self.assertEqual(len(x), 1)
-            self.assertTrue(x is x[0])
+            self.assertIs(x, x[0])
 
     def test_recursive_tuple(self):
         t = ([],)
@@ -610,7 +610,7 @@ class AbstractPickleTests(unittest.TestCase):
             x = self.loads(s)
             self.assertEqual(len(x), 1)
             self.assertEqual(len(x[0]), 1)
-            self.assertTrue(x is x[0][0])
+            self.assertIs(x, x[0][0])
 
     def test_recursive_dict(self):
         d = {}
@@ -619,7 +619,7 @@ class AbstractPickleTests(unittest.TestCase):
             s = self.dumps(d, proto)
             x = self.loads(s)
             self.assertEqual(list(x.keys()), [1])
-            self.assertTrue(x[1] is x)
+            self.assertIs(x[1], x)
 
     def test_recursive_inst(self):
         i = C()
@@ -642,7 +642,7 @@ class AbstractPickleTests(unittest.TestCase):
             self.assertEqual(len(x), 1)
             self.assertEqual(dir(x[0]), dir(i))
             self.assertEqual(list(x[0].attr.keys()), [1])
-            self.assertTrue(x[0].attr[1] is x)
+            self.assertIs(x[0].attr[1], x)
 
     def test_get(self):
         self.assertRaises(KeyError, self.loads, b'g0\np0')
@@ -912,7 +912,7 @@ class AbstractPickleTests(unittest.TestCase):
             for x in None, False, True:
                 s = self.dumps(x, proto)
                 y = self.loads(s)
-                self.assertTrue(x is y, (proto, x, s, y))
+                self.assertIs(x, y, (proto, x, s, y))
                 expected = expected_opcode[proto, x]
                 self.assertEqual(opcode_in_pickle(expected, s), True)
 
@@ -1036,7 +1036,7 @@ class AbstractPickleTests(unittest.TestCase):
             if proto == 0:
                 self.assertEqual(num_appends, 0)
             else:
-                self.assertTrue(num_appends >= 2)
+                self.assertGreaterEqual(num_appends, 2)
 
     def test_dict_chunking(self):
         n = 10  # too small to chunk
@@ -1059,7 +1059,7 @@ class AbstractPickleTests(unittest.TestCase):
             if proto == 0:
                 self.assertEqual(num_setitems, 0)
             else:
-                self.assertTrue(num_setitems >= 2)
+                self.assertGreaterEqual(num_setitems, 2)
 
     def test_simple_newobj(self):
         x = object.__new__(SimpleNewObj)  # avoid __init__
@@ -1444,8 +1444,8 @@ class BigmemPickleTests(unittest.TestCase):
                     continue
                 try:
                     pickled = self.dumps(data, protocol=proto)
-                    self.assertTrue(b"abcd" in pickled[:15])
-                    self.assertTrue(b"abcd" in pickled[-15:])
+                    self.assertIn(b"abcd", pickled[:15])
+                    self.assertIn(b"abcd", pickled[-15:])
                 finally:
                     pickled = None
         finally:
@@ -1473,8 +1473,8 @@ class BigmemPickleTests(unittest.TestCase):
             for proto in protocols:
                 try:
                     pickled = self.dumps(data, protocol=proto)
-                    self.assertTrue(b"abcd" in pickled[:15])
-                    self.assertTrue(b"abcd" in pickled[-15:])
+                    self.assertIn(b"abcd", pickled[:15])
+                    self.assertIn(b"abcd", pickled[-15:])
                 finally:
                     pickled = None
         finally:
@@ -1819,7 +1819,7 @@ class AbstractPicklerUnpicklerObjectTests(unittest.TestCase):
         primed.memo.clear()
 
         self.assertEqual(unpickled_data2, data)
-        self.assertTrue(unpickled_data2 is unpickled_data1)
+        self.assertIs(unpickled_data2, unpickled_data1)
 
     def test_reusing_unpickler_objects(self):
         data1 = ["abcdefg", "abcdefg", 44]
